@@ -1,6 +1,8 @@
 package command
 
 import (
+	"fmt"
+
 	"github.com/hashicorp/hcl/v2"
 	packerregistry "github.com/hashicorp/packer/internal/registry"
 	"github.com/hashicorp/packer/packer"
@@ -57,8 +59,10 @@ func (c *CoreWrapper) ConfiguredArtifactMetadataPublisher() (*packerregistry.Buc
 	if err != nil {
 		return nil, hcl.Diagnostics{
 			&hcl.Diagnostic{
-				Summary:  "Invalid HCP Packer Registry configuration",
-				Detail:   err.Error(),
+				Summary: "Invalid HCP Packer configuration",
+				Detail: fmt.Sprintf("Packer could not validate the provided "+
+					"HCP Packer registry configuration. Check the error message for details "+
+					"or contact HCP Packer support for further assistance.\nError: %s", err),
 				Severity: hcl.DiagError,
 			},
 		}
