@@ -2,34 +2,39 @@ package command
 
 import (
 	"path/filepath"
+	"strings"
 	"testing"
+
+	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
+	"github.com/stretchr/testify/assert"
 )
 
-func TestFix_noArgs(t *testing.T) {
-	c := &PushCommand{Meta: testMeta(t)}
-	code := c.Run(nil)
-	if code != 1 {
-		t.Fatalf("bad: %#v", code)
-	}
-}
-
-func TestFix_multiArgs(t *testing.T) {
-	c := &PushCommand{Meta: testMeta(t)}
-	code := c.Run([]string{"one", "two"})
-	if code != 1 {
-		t.Fatalf("bad: %#v", code)
-	}
-}
-
 func TestFix(t *testing.T) {
+	s := &strings.Builder{}
+	ui := &packersdk.BasicUi{
+		Writer: s,
+	}
 	c := &FixCommand{
 		Meta: testMeta(t),
 	}
 
+	c.Ui = ui
+
 	args := []string{filepath.Join(testFixture("fix"), "template.json")}
 	if code := c.Run(args); code != 0 {
 		fatalCommand(t, c.Meta)
 	}
+	expected := `{
+  "builders": [
+    {
+      "type": "dummy"
+    }
+  ],
+  "push": {
+    "name": "foo/bar"
+  }
+}`
+	assert.Equal(t, expected, strings.TrimSpace(s.String()))
 }
 
 func TestFix_invalidTemplate(t *testing.T) {
