@@ -14,6 +14,7 @@ import (
 	"github.com/hashicorp/packer/builder/null"
 	dnull "github.com/hashicorp/packer/datasource/null"
 	. "github.com/hashicorp/packer/hcl2template/internal"
+	hcl2template "github.com/hashicorp/packer/hcl2template/internal"
 	packerregistry "github.com/hashicorp/packer/internal/registry"
 	"github.com/hashicorp/packer/packer"
 	"github.com/zclconf/go-cty/cty"
@@ -372,6 +373,7 @@ var cmpOpts = []cmp.Option{
 	cmpopts.IgnoreFields(VariableAssignment{},
 		"Expr", // its an interface
 	),
+	cmpopts.IgnoreTypes(hcl2template.MockBuilder{}),
 	cmpopts.IgnoreTypes(HCL2Ref{}),
 	cmpopts.IgnoreTypes([]*LocalBlock{}),
 	cmpopts.IgnoreTypes([]hcl.Range{}),
