@@ -2,7 +2,6 @@ package registry
 
 import (
 	"context"
-	"os"
 	"strconv"
 	"testing"
 
@@ -10,16 +9,14 @@ import (
 )
 
 func createInitialTestBucket(t testing.TB) *Bucket {
-	oldEnv := os.Getenv("HCP_PACKER_BUILD_FINGERPRINT")
-	os.Setenv("HCP_PACKER_BUILD_FINGERPRINT", "no-fingerprint-here")
-	defer func() {
-		os.Setenv("HCP_PACKER_BUILD_FINGERPRINT", oldEnv)
-	}()
+	t.Setenv("HCP_PACKER_BUILD_FINGERPRINT", "no-fingerprint-here")
 
 	t.Helper()
-	bucket, err := NewBucketWithIteration(IterationOptions{})
+	bucket := NewBucketWithIteration()
+	err := bucket.Iteration.Initialize(IterationOptions{})
 	if err != nil {
-		t.Fatalf("failed when calling NewBucketWithIteration: %s", err)
+		t.Errorf("failed to initialize Bucket: %s", err)
+		return nil
 	}
 
 	mockService := NewMockPackerClientService()
@@ -283,15 +280,15 @@ func TestBucket_PopulateIteration(t *testing.T) {
 		tt := tt
 		t.Run(tt.desc, func(t *testing.T) {
 
-			os.Setenv("HCP_PACKER_BUILD_FINGERPRINT", "test-run-"+strconv.Itoa(i))
-			defer os.Unsetenv("HCP_PACKER_BUILD_FINGERPRINT")
+			t.Setenv("HCP_PACKER_BUILD_FINGERPRINT", "test-run-"+strconv.Itoa(i))
 
 			mockService := NewMockPackerClientService()
 			mockService.BucketAlreadyExist = true
 			mockService.IterationAlreadyExist = true
 			mockService.BuildAlreadyDone = tt.buildCompleted
 
-			bucket, err := NewBucketWithIteration(IterationOptions{})
+			bucket := NewBucketWithIteration()
+			err := bucket.Iteration.Initialize(IterationOptions{})
 			if err != nil {
 				t.Fatalf("failed when calling NewBucketWithIteration: %s", err)
 			}
